@@ -4,6 +4,9 @@ import boto3
 from botocore.exceptions import ClientError
 from django.conf import settings
 from django.core.mail import EmailMessage
+import zipfile
+import os
+
 logger = logging.getLogger('dict_config_logger')
 
 
@@ -43,6 +46,13 @@ def list_email_verified():
     return response['Identities']
 
 
+def zipdir(path, ziph):
+    # ziph is zipfile handle
+    for root, dirs, files in os.walk(path):
+        for file in files:
+            ziph.write(os.path.join(root, file))
+
+
 def send_notifications(email, sender, email_configuration):
     """This function sends email of a log file """
 
@@ -62,6 +72,10 @@ def send_notifications(email, sender, email_configuration):
     # LOG_PATH = email_configuration.get('Log_path')
     ATTACHMENT = getattr(settings, "LOG_PATH", None)
 
+    zipf = zipfile.ZipFile('Zipped_file.zip', 'w', zipfile.ZIP_DEFLATED)
+    zipdir(ATTACHMENT, zipf)
+    zipf.close()
+
     # The HTML body of the email.
     file_name = email_configuration.get('HTML_File')
     BODY_HTML = open('media/' + file_name).read().format(
@@ -71,7 +85,8 @@ def send_notifications(email, sender, email_configuration):
         faq_url=email_configuration.get('FAQ_URL'),
         unsubscribe=email_configuration.get('Unsubscribe_Email_ID'))
     # Define the attachment part and encode it using MIMEApplication.
-    att = MIMEApplication(open(ATTACHMENT, 'rb').read())
+    att = MIMEApplication(open('Zipped_file.zip', 'rb').read())
+    os.remove('Zipped_file.zip')
 
     # Add a header to tell the email client to treat this part as an
     # attachment, and to give the attachment a name.
